Changelog
=========

This document describes changes in the installer between each past release.

0.19.1.1 (2019-12-05)
---------------------

- Set the elm file mode to be executable


0.19.1 (2019-12-05)
-------------------

- Upgrade to install 0.19.1


0.19.0.2 (2019-04-04)
---------------------

- Create a setup.py that allow for install.
